import sys

from . import start_example_task

if __name__ == "__main__":
    start_example_task()
